Evohome Client
==============

Purpose
-------

The Evohome client provides a straightforward API to allow access to your Evohome data.

Getting started
---------------

You'll need to have signed up for an account at http://www.mytotalconnect.com - you'll use the username and password credentials below.

Install the evohome client library:

.. code-block:: none

    pip install evohomeclient

Versions
--------

Honeywell currently have two version of their API.

Version 1 is simpler, but doesn't have capabilities such as viewing and changing the schedules on the evohome system.

Version 2 was released towards the end of October 2014 and has a lot more information available, including the functionality to change the schedules for individual zones.

Contents:

.. toctree::
   :maxdepth: 2

   api1/index
   api2/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
